@@ -34,7 +34,7 @@ struct ECalListenerPrivate {
 	gpointer fn_data;
 
 	/* Whether notification is desired */
-	gboolean notify : 1;
+	guint notify : 1;
 };
 
 /* Signal IDs */
@@ -95,6 +95,8 @@ convert_status (const GNOME_Evolution_Calendar_CallStatus status)
 		return E_CALENDAR_STATUS_UNKNOWN_USER;
 	case GNOME_Evolution_Calendar_InvalidServerVersion:
 		return E_CALENDAR_STATUS_INVALID_SERVER_VERSION;
+	case GNOME_Evolution_Calendar_NoSuchCal:
+	      return E_CALENDAR_STATUS_NO_SUCH_CALENDAR;
 	
 	case GNOME_Evolution_Calendar_OtherError:
 	default:
@@ -814,7 +816,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, open),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);	
 	signals[REMOVE] =
 		g_signal_new ("remove",
@@ -822,7 +824,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, remove),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 	signals[CREATE_OBJECT] =
 		g_signal_new ("create_object",
@@ -838,7 +840,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, modify_object),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);	
 	signals[REMOVE_OBJECT] =
 		g_signal_new ("remove_object",
@@ -846,7 +848,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, remove_object),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 	signals[DISCARD_ALARM] =
 		g_signal_new ("discard_alarm",
@@ -854,7 +856,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, discard_alarm),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 	signals[RECEIVE_OBJECTS] =
 		g_signal_new ("receive_objects",
@@ -862,7 +864,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, receive_objects),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 	signals[SEND_OBJECTS] =
 		g_signal_new ("send_objects",
@@ -926,7 +928,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, set_default_timezone),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE, 1, G_TYPE_INT);
 	signals[GET_CHANGES] =
 		g_signal_new ("get_changes",
@@ -958,7 +960,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, auth_required),
 			      NULL, NULL,
-			      e_cal_marshal_NONE__NONE,
+			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 	signals[BACKEND_ERROR] =
 		g_signal_new ("backend_error",
@@ -966,7 +968,7 @@ e_cal_listener_class_init (ECalListenerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (ECalListenerClass, backend_error),
 			      NULL, NULL,
-			      e_cal_marshal_VOID__STRING,
+			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
