@@ -5,16 +5,16 @@
  *  Copyright 2003 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
@@ -25,12 +25,13 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_KRB5
+#include <errno.h>
 
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
+#ifdef HAVE_KRB5
 #include <netdb.h>
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/types.h>
 #ifdef HAVE_ET_COM_ERR_H
 #include <et/com_err.h>
 #else
@@ -39,17 +40,25 @@
 #ifdef HAVE_MIT_KRB5
 #include <gssapi/gssapi.h>
 #include <gssapi/gssapi_generic.h>
-#else /* HAVE_HEIMDAL_KRB5 */
+#endif
+#ifdef HAVE_HEIMDAL_KRB5
 #include <gssapi.h>
 #define gss_nt_service_name GSS_C_NT_HOSTBASED_SERVICE
+#else
+#ifdef  HAVE_SUN_KRB5 
+#include <gssapi/gssapi.h>
+#include <gssapi/gssapi_ext.h>
+extern gss_OID gss_nt_service_name;
+#endif
 #endif
-#include <errno.h>
 
 #ifndef GSS_C_OID_KRBV5_DES
 #define GSS_C_OID_KRBV5_DES GSS_C_NO_OID
 #endif
 
-#include "camel-i18n.h"
+#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
+
 #include "camel-net-utils.h"
 #include "camel-sasl-gssapi.h"
 
