@@ -7,15 +7,15 @@
  * Copyright (C) 2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -25,12 +25,6 @@
 #ifndef CAMEL_GROUPWISE_STORE_H
 #define CAMEL_GROUPWISE_STORE_H 1
 
-
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #include <camel/camel-store.h>
 #include <camel/camel-offline-store.h>
 #include "camel-groupwise-store-summary.h"
@@ -45,6 +39,8 @@ extern "C" {
 
 #define GW_PARAM_FILTER_INBOX		(1 << 0)
 
+G_BEGIN_DECLS
+
 typedef struct _CamelGroupwiseStore CamelGroupwiseStore;
 typedef struct _CamelGroupwiseStoreClass CamelGroupwiseStoreClass;
 typedef struct _CamelGroupwiseStorePrivate CamelGroupwiseStorePrivate;
@@ -54,12 +50,14 @@ struct _CamelGroupwiseStore {
 
 	struct _CamelGroupwiseStoreSummary *summary;
 
-	char *root_container ;
+	char *root_container;
 	CamelGroupwiseStorePrivate *priv;
-	CamelFolder *current_folder ;
+	CamelFolder *current_folder;
 	
 	/* the parameters field is not to be included not. probably for 2.6*/
 	/*guint32 parameters;*/
+	time_t refresh_stamp;
+	guint list_loaded;
 };
 
 
@@ -70,18 +68,18 @@ struct _CamelGroupwiseStoreClass {
 
 /* Standard Camel function */
 CamelType camel_groupwise_store_get_type (void);
-char * groupwise_get_name(CamelService *service, gboolean brief) ;
+char * groupwise_get_name(CamelService *service, gboolean brief);
 
 /*IMplemented*/
-const char *camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const char *folder_name) ;
-const char *camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const char *container_id) ;
-EGwConnection *cnc_lookup (CamelGroupwiseStorePrivate *priv) ;
-char *storage_path_lookup (CamelGroupwiseStorePrivate *priv) ;
+const char *camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const char *folder_name);
+const char *camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const char *container_id);
+EGwConnection *cnc_lookup (CamelGroupwiseStorePrivate *priv);
+char *storage_path_lookup (CamelGroupwiseStorePrivate *priv);
+const char *groupwise_base_url_lookup (CamelGroupwiseStorePrivate *priv);
 CamelFolderInfo * create_junk_folder (CamelStore *store);
+gboolean camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex);
+void gw_store_reload_folder (CamelGroupwiseStore *store, CamelFolder *folder, guint32 flags, CamelException *ex);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* CAMEL_GROUPWISE_STORE_H */
