@@ -3,7 +3,7 @@
  * Copyright (C) 2005 Novell, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -28,6 +28,7 @@
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrenderertoggle.h>
 #include <gtk/gtkentry.h>
+#include <gtk/gtkfilechooserbutton.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmessagedialog.h>
@@ -35,9 +36,9 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
-#include <libgnomeui/gnome-file-entry.h>
 #include <glade/glade-xml.h>
 #include <libedataserver/e-categories.h>
+#include <libedataserver/libedataserver-private.h>
 #include "e-categories-dialog.h"
 
 struct _ECategoriesDialogPrivate {
@@ -68,11 +69,16 @@ static CategoryPropertiesDialog *
 load_properties_dialog (ECategoriesDialog *parent)
 {
 	CategoryPropertiesDialog *prop_dialog;
-	GtkWidget *table;
+	char *gladefile;
 
 	prop_dialog = g_new0 (CategoryPropertiesDialog, 1);
 
-	prop_dialog->gui = glade_xml_new (E_DATA_SERVER_UI_GLADEDIR "/e-categories-dialog.glade", "properties-dialog", NULL);
+	gladefile = g_build_filename (E_DATA_SERVER_UI_GLADEDIR,
+				      "e-categories-dialog.glade",
+				      NULL);
+	prop_dialog->gui = glade_xml_new (gladefile, "properties-dialog", GETTEXT_PACKAGE);
+	g_free (gladefile);
+
 	if (!prop_dialog->gui) {
 		g_free (prop_dialog);
 		return NULL;
@@ -85,13 +91,7 @@ load_properties_dialog (ECategoriesDialog *parent)
 
 	prop_dialog->category_name = glade_xml_get_widget (prop_dialog->gui, "category-name");
 	prop_dialog->category_color = glade_xml_get_widget (prop_dialog->gui, "category-color");
-
-	/* create the icon file entry */
-	table = glade_xml_get_widget (prop_dialog->gui, "table-category-properties");
-	prop_dialog->category_icon = gnome_file_entry_new ("category-icon-history-id", _("Category Icon"));
-	gtk_table_attach (GTK_TABLE (table), prop_dialog->category_icon, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 3, 3);
-	gtk_widget_show (prop_dialog->category_icon);
-	gnome_file_entry_set_modal ((GnomeFileEntry *)prop_dialog->category_icon, TRUE);
+	prop_dialog->category_icon = glade_xml_get_widget (prop_dialog->gui, "category-icon");
 
 	return prop_dialog;
 }
@@ -161,7 +161,7 @@ add_comma_sep_categories (gpointer key, gpointer value, gpointer user_data)
 {
 	GString **str = user_data;
 
-	if (strlen ((GString *) (*str)->str) > 0)
+	if (strlen ((*str)->str) > 0)
 		*str = g_string_append (*str, ",");
 
 	*str = g_string_append (*str, (const char *) key);
@@ -212,6 +212,29 @@ entry_changed_cb (GtkEditable *editable, gpointer user_data)
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, TRUE);
 }
 
+static char *
+check_category_name (const char *name)
+{
+	GString *str = NULL;
+	char *p = (char *) name;
+
+	str = g_string_new ("");
+	while (*p) {
+		switch (*p) {
+		case ',' :
+			break;
+		default :
+			str = g_string_append_c (str, *p);
+		}
+		p++;
+	}
+
+	p = str->str;
+	g_string_free (str, FALSE);
+
+	return p;
+}
+
 static void
 new_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
@@ -224,37 +247,49 @@ new_button_clicked_cb (GtkButton *button, gpointer user_data)
 	if (!prop_dialog)
 		return;
 
-	if (gtk_dialog_run (GTK_DIALOG (prop_dialog->the_dialog)) == GTK_RESPONSE_OK) {
-		const char *category_name, *category_icon;
-		GtkTreeIter iter;
+	do {
+		if (gtk_dialog_run (GTK_DIALOG (prop_dialog->the_dialog)) == GTK_RESPONSE_OK) {
+			const char *category_name, *category_icon;
+			char *correct_category_name;
+			GtkTreeIter iter;
 
-		category_name = gtk_entry_get_text (GTK_ENTRY (prop_dialog->category_name));
-		if (e_categories_exist (category_name)) {
-			GtkWidget *error_dialog;
+			category_name = gtk_entry_get_text (GTK_ENTRY (prop_dialog->category_name));
+			correct_category_name = check_category_name (category_name);
 
-			error_dialog = gtk_message_dialog_new (
-				GTK_WINDOW (prop_dialog->the_dialog),
-				0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-				_("There is already a category '%s' in the configuration. Please use another name"),
-				category_name);
+			if (e_categories_exist (correct_category_name)) {
+				GtkWidget *error_dialog;
 
-			gtk_dialog_run (GTK_DIALOG (error_dialog));
-			gtk_widget_destroy (error_dialog);
-		} else {
-			/* FIXME: get color */
-			category_icon = gtk_entry_get_text (
-				GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (prop_dialog->category_icon))));
+				error_dialog = gtk_message_dialog_new (
+					GTK_WINDOW (prop_dialog->the_dialog),
+					0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+					_("There is already a category '%s' in the configuration. Please use another name"),
+					category_name);
 
-			e_categories_add (category_name, NULL, category_icon ? category_icon : NULL, TRUE);
+				gtk_dialog_run (GTK_DIALOG (error_dialog));
+				gtk_widget_destroy (error_dialog);
+				g_free (correct_category_name);
+			} else {
+				/* FIXME: get color */
+				category_icon = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (prop_dialog->category_icon));
 
-			gtk_list_store_append (
-				GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (prop_dialog->parent->priv->categories_list))),
-				&iter);
-			gtk_list_store_set (
-				GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (prop_dialog->parent->priv->categories_list))),
-				&iter, 0, FALSE, 1, category_name, -1);
-		}
-	}
+				e_categories_add (correct_category_name, NULL, category_icon ? category_icon : NULL, TRUE);
+
+				gtk_list_store_append (
+					GTK_LIST_STORE (gtk_tree_view_get_model (
+								GTK_TREE_VIEW (prop_dialog->parent->priv->categories_list))),
+					&iter);
+				gtk_list_store_set (
+					GTK_LIST_STORE (gtk_tree_view_get_model (
+								GTK_TREE_VIEW (prop_dialog->parent->priv->categories_list))),
+					&iter, 0, FALSE, 1, correct_category_name, -1);
+
+				g_free (correct_category_name);
+
+				break;
+			}
+		} else
+			break;
+	} while (TRUE);
 
 	free_properties_dialog (prop_dialog);
 }
@@ -287,16 +322,14 @@ edit_button_clicked_cb (GtkButton *button, gpointer user_data)
 	gtk_tree_model_get (model, &iter, 1, &category_name, -1);
 	gtk_entry_set_text (GTK_ENTRY (prop_dialog->category_name), category_name);
 	gtk_widget_set_sensitive (prop_dialog->category_name, FALSE);
-	gtk_entry_set_text (
-		GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (prop_dialog->category_icon))),
-		e_categories_get_icon_file_for (category_name));
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (prop_dialog->category_icon), 
+				       e_categories_get_icon_file_for (category_name));
 
 	if (gtk_dialog_run (GTK_DIALOG (prop_dialog->the_dialog)) == GTK_RESPONSE_OK) {
 		const char *category_icon;
 
 		/* FIXME: get color */
-		category_icon = gtk_entry_get_text (
-			GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (prop_dialog->category_icon))));
+		category_icon = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (prop_dialog->category_icon));
 
 		if (category_icon)
 			e_categories_set_icon_file_for (category_name, category_icon);
@@ -339,13 +372,19 @@ e_categories_dialog_init (ECategoriesDialog *dialog)
 	GtkTreeViewColumn *column;
 	GtkListStore *model;
 	GtkWidget *main_widget;
+	char *gladefile;
 
 	priv = g_new0 (ECategoriesDialogPrivate, 1);
 	priv->selected_categories = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 	dialog->priv = priv;
 
 	/* load the UI from our Glade file */
-	priv->gui = glade_xml_new (E_DATA_SERVER_UI_GLADEDIR "/e-categories-dialog.glade", "table-categories", NULL);
+	gladefile = g_build_filename (E_DATA_SERVER_UI_GLADEDIR,
+				      "e-categories-dialog.glade",
+				      NULL);
+	priv->gui = glade_xml_new (gladefile, "table-categories", GETTEXT_PACKAGE);
+	g_free (gladefile);
+
 	if (!priv->gui) {
 		g_warning (G_STRLOC ": can't load e-categories-dialog.glade file");
 		return;
@@ -405,10 +444,10 @@ e_categories_dialog_init (ECategoriesDialog *dialog)
  * e_categories_dialog_new:
  * @initial_category_list: Comma-separated list of initial categories.
  *
- * Creates a new %ECategoriesDialog widget.
+ * Creates a new #ECategoriesDialog widget.
  *
- * Return value: A pointer to the newly created %ECategoriesDialog widget.
- */
+ * Return value: A pointer to the newly created #ECategoriesDialog widget.
+ **/
 GtkWidget *
 e_categories_dialog_new (const char *initial_category_list)
 {
@@ -418,7 +457,8 @@ e_categories_dialog_new (const char *initial_category_list)
 	if (initial_category_list)
 		e_categories_dialog_set_categories (dialog, initial_category_list);
 
-	g_signal_connect (G_OBJECT (dialog->priv->categories_entry), "changed", entry_changed_cb, dialog);
+	g_signal_connect (G_OBJECT (dialog->priv->categories_entry), "changed", 
+			  G_CALLBACK (entry_changed_cb), dialog);
 
 	return GTK_WIDGET (dialog);
 }
@@ -430,7 +470,7 @@ e_categories_dialog_new (const char *initial_category_list)
  * Gets a comma-separated list of the categories currently selected on the dialog.
  *
  * Return value: comma-separated list of categories.
- */
+ **/
 const char *
 e_categories_dialog_get_categories (ECategoriesDialog *dialog)
 {
@@ -449,7 +489,7 @@ e_categories_dialog_get_categories (ECategoriesDialog *dialog)
  * @categories: Comma-separated list of categories.
  *
  * Sets the list of categories selected on the dialog.
- */
+ **/
 void
 e_categories_dialog_set_categories (ECategoriesDialog *dialog, const char *categories)
 {
