@@ -5,15 +5,15 @@
  * Copyright (C) 2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
@@ -43,14 +43,14 @@ static void         e_destination_store_init            (EDestinationStore
 static void         e_destination_store_class_init      (EDestinationStoreClass *class);
 static void         e_destination_store_tree_model_init (GtkTreeModelIface  *iface);
 static void         e_destination_store_finalize        (GObject            *object);
-static guint        e_destination_store_get_flags       (GtkTreeModel       *tree_model);
+static GtkTreeModelFlags e_destination_store_get_flags       (GtkTreeModel       *tree_model);
 static gint         e_destination_store_get_n_columns   (GtkTreeModel       *tree_model);
 static GType        e_destination_store_get_column_type (GtkTreeModel       *tree_model,
 							 gint                index);
 static gboolean     e_destination_store_get_iter        (GtkTreeModel       *tree_model,
 							 GtkTreeIter        *iter,
 							 GtkTreePath        *path);
-static GtkTreePath *e_destination_store_get_path        (GtkTreeModel       *tree_model,
+GtkTreePath *e_destination_store_get_path        (GtkTreeModel       *tree_model,
 							 GtkTreeIter        *iter);
 static void         e_destination_store_get_value       (GtkTreeModel       *tree_model,
 							 GtkTreeIter        *iter,
@@ -74,6 +74,7 @@ static gboolean     e_destination_store_iter_parent     (GtkTreeModel       *tre
 							 GtkTreeIter        *child);
 
 static void destination_changed (EDestinationStore *destination_store, EDestination *destination);
+static void stop_destination    (EDestinationStore *destination_store, EDestination *destination);
 
 /* ------------------ *
  * Class/object setup *
@@ -160,7 +161,17 @@ e_destination_store_init (EDestinationStore *destination_store)
 static void
 e_destination_store_finalize (GObject *object)
 {
-	/* TODO: Free stuff */
+	EDestinationStore *destination_store = E_DESTINATION_STORE (object);
+	gint               i;
+
+	for (i = 0; i < destination_store->destinations->len; i++) {
+		EDestination *destination = g_ptr_array_index (destination_store->destinations, i);
+
+		stop_destination (destination_store, destination);
+		g_object_unref (destination);
+	}
+
+	g_ptr_array_free (destination_store->destinations, TRUE);
 
 	if (G_OBJECT_CLASS (parent_class)->finalize)
 		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
@@ -247,6 +258,23 @@ find_destination_by_pointer (EDestinationStore *destination_store, EDestination
 	return -1;
 }
 
+static gint
+find_destination_by_email (EDestinationStore *destination_store, EDestination *destination)
+{
+	gint i;
+	const char *e_mail = e_destination_get_email (destination);
+
+	for (i = 0; i < destination_store->destinations->len; i++) {
+		EDestination *destination_here = g_ptr_array_index (destination_store->destinations, i);
+		const char *mail = e_destination_get_email (destination_here);
+
+		if (g_str_equal (e_mail, mail))
+			return i;
+	}
+
+	return -1;
+}
+
 static void
 start_destination (EDestinationStore *destination_store, EDestination *destination)
 {
@@ -326,6 +354,8 @@ e_destination_store_list_destinations (EDestinationStore *destination_store)
 		EDestination *destination = g_ptr_array_index (destination_store->destinations, i);
 		destination_list = g_list_prepend (destination_list, destination);
 	}
+	
+	destination_list = g_list_reverse(destination_list);
 
 	return destination_list;
 }
@@ -382,7 +412,7 @@ e_destination_store_append_destination (EDestinationStore *destination_store, ED
 {
 	g_return_if_fail (E_IS_DESTINATION_STORE (destination_store));
 
-	if (find_destination_by_pointer (destination_store, destination) >= 0) {
+	if (find_destination_by_email (destination_store, destination) >= 0 && !e_destination_is_evolution_list (destination)) {
 		g_warning ("Same destination added more than once to EDestinationStore!");
 		return;
 	}
@@ -422,11 +452,32 @@ e_destination_store_remove_destination (EDestinationStore *destination_store, ED
 	row_deleted (destination_store, n);
 }
 
+void
+e_destination_store_remove_destination_nth (EDestinationStore *destination_store, int n)
+{
+	EDestination *destination;
+	
+	g_return_if_fail ( n >= 0);
+
+	destination = g_ptr_array_index(destination_store->destinations, n);
+	stop_destination (destination_store, destination);
+	g_object_unref (destination);
+
+	g_ptr_array_remove_index (destination_store->destinations, n);
+	row_deleted (destination_store, n);
+}
+
+guint
+e_destination_store_get_destination_count (EDestinationStore *destination_store)
+{
+	return destination_store->destinations->len;
+}
+
 /* ---------------- *
  * GtkTreeModel API *
  * ---------------- */
 
-static guint
+static GtkTreeModelFlags
 e_destination_store_get_flags (GtkTreeModel *tree_model)
 {
 	g_return_val_if_fail (E_IS_DESTINATION_STORE (tree_model), 0);
@@ -469,7 +520,7 @@ e_destination_store_get_iter (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTr
 	return TRUE;
 }
 
-static GtkTreePath *
+GtkTreePath *
 e_destination_store_get_path (GtkTreeModel *tree_model,
 			      GtkTreeIter  *iter)
 {
@@ -593,7 +644,9 @@ e_destination_store_get_value (GtkTreeModel *tree_model,
 	EDestinationStore *destination_store = E_DESTINATION_STORE (tree_model);
 	EDestination      *destination;
 	const gchar       *string;
+	GString 	  *string_new;
 	gint               row;
+	EContact	  *contact;
 
 	g_return_if_fail (E_IS_DESTINATION_STORE (tree_model));
 	g_return_if_fail (column < E_DESTINATION_STORE_NUM_COLUMNS);
@@ -620,8 +673,25 @@ e_destination_store_get_value (GtkTreeModel *tree_model,
 			break;
 
 		case E_DESTINATION_STORE_COLUMN_ADDRESS:
-			string = e_destination_get_address (destination);
-			g_value_set_string (value, string);
+			contact = e_destination_get_contact(destination);
+			if (contact && E_IS_CONTACT (contact)) {
+				if(e_contact_get (contact, E_CONTACT_IS_LIST)) {
+					string = e_destination_get_name (destination);
+					string_new = g_string_new(string);
+					string_new = g_string_append(string_new, " mailing list");
+					g_value_set_string (value, string_new->str);
+					g_string_free(string_new, TRUE);
+				}
+				else {
+					string = e_destination_get_address (destination);
+					g_value_set_string (value, string);
+				}
+			}
+			else {
+				string = e_destination_get_address (destination);
+				g_value_set_string (value, string);
+
+			}
 			break;
 
 		default:
